pub struct SingleSourceDijkstra { /* private fields */ }Expand description
Find single-source shortest paths to all reachable nodes.
This runs Dijkstra’s algorithm from a single source and returns the shortest distance to all reachable nodes.
Implementations
Sourceimpl SingleSourceDijkstra
impl SingleSourceDijkstra
Sourcepub fn new(source: EntityId, direction: Direction) -> Self
pub fn new(source: EntityId, direction: Direction) -> Self
Create a new single-source Dijkstra finder.
Sourcepub fn with_weight_property(self, property: impl Into<String>) -> Self
pub fn with_weight_property(self, property: impl Into<String>) -> Self
Set the weight property name to use.
Sourcepub fn with_max_weight(self, max_weight: f64) -> Self
pub fn with_max_weight(self, max_weight: f64) -> Self
Set the maximum total weight to search.
Sourcepub fn with_edge_type(self, edge_type: impl Into<EdgeType>) -> Self
pub fn with_edge_type(self, edge_type: impl Into<EdgeType>) -> Self
Filter to only traverse edges of the specified type.