pub struct BetweennessCentrality;Expand description
Betweenness Centrality algorithm implementation.
Betweenness centrality quantifies the number of times a node acts as a bridge along the shortest path between two other nodes.
Implementations
Sourceimpl BetweennessCentrality
impl BetweennessCentrality
Sourcepub fn compute<T: Transaction>(
tx: &T,
config: &BetweennessCentralityConfig,
) -> GraphResult<CentralityResult>
pub fn compute<T: Transaction>( tx: &T, config: &BetweennessCentralityConfig, ) -> GraphResult<CentralityResult>
Sourcepub fn compute_for_nodes<T: Transaction>(
tx: &T,
nodes: &[EntityId],
config: &BetweennessCentralityConfig,
) -> GraphResult<CentralityResult>
pub fn compute_for_nodes<T: Transaction>( tx: &T, nodes: &[EntityId], config: &BetweennessCentralityConfig, ) -> GraphResult<CentralityResult>
Compute betweenness centrality for a subset of nodes.
Only considers shortest paths within the specified subgraph.
Arguments
tx- The transaction to use for graph accessnodes- The nodes to include in the computationconfig- Configuration parameters for the algorithm