ConnectedComponentsConfig

Struct ConnectedComponentsConfig 

pub struct ConnectedComponentsConfig {
    pub max_graph_nodes: Option<usize>,
}
Configuration for Connected Components algorithms.

Fields

max_graph_nodes: Option<usize>

Maximum number of nodes allowed before returning an error. Set to None to disable the check. Default: 10,000,000 (10M nodes)

Implementations

Source

impl ConnectedComponentsConfig

pub fn new() -> Self

Create a new configuration with default values.

pub const fn with_max_graph_nodes(self, limit: Option<usize>) -> Self

Set the maximum number of nodes allowed.

If the graph has more nodes than this limit, the algorithm will return a GraphError::GraphTooLarge error instead of attempting to allocate potentially gigabytes of memory.

Set to None to disable the check (use with caution).